Bootstrap Components › Buttons — Stisla

# Buttons

Use Bootstrap’s custom button styles for actions in forms, dialogs, and more with support for multiple sizes, states, and more.

#### Basic

Use the `.btn .btn-{color}` classes.

Primary Secondary Info Warning Danger Success Light Dark Link

#### Buttons `.btn-outline`

Use the `.btn .btn-outline-{color}` classes.

Primary Secondary Info Warning Danger Success Light Dark

#### Button Sizes

Use the `.btn-lg` or `.btn-sm` classes.

Small Normal Large

#### Button States

Use the `.disabled` or `.btn-progress` classes.

Normal Disabled Progress

#### Icon Button

Use the `.btn-icon` and `.icon-left` classes.

Default Primary Secondary Info Warning Danger Success Light Dark

#### Only Icon Button

Use the `.btn-icon` class.

Sizes.

#### Button Group

#### Vertical Variation